summaryrefslogtreecommitdiff
path: root/source4/torture/raw/notify.c
diff options
context:
space:
mode:
Diffstat (limited to 'source4/torture/raw/notify.c')
-rw-r--r--source4/torture/raw/notify.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source4/torture/raw/notify.c b/source4/torture/raw/notify.c
index fdb5771bf3d..afb4a8eb5f2 100644
--- a/source4/torture/raw/notify.c
+++ b/source4/torture/raw/notify.c
@@ -1462,7 +1462,7 @@ static bool test_notify_tree(struct torture_context *tctx,
talloc_free(path);
}
/* give a bit of time for the events to propogate */
tv = timeval_current();
do {
@@ -1485,7 +1485,7 @@ static bool test_notify_tree(struct torture_context *tctx,
}
} while (!all_done && timeval_elapsed(&tv) < 20);
- torture_comment(tctx, "took %.4f seconds to propogate all events\n", timeval_elapsed(&tv));
+ torture_comment(tctx, "took %.4f seconds to propagate all events\n", timeval_elapsed(&tv));
for (i=0;i<ARRAY_SIZE(dirs);i++) {
torture_assert_int_equal_goto(tctx,
@@ -1462,7 +1462,7 @@ static bool test_notify_tree(struct torture_context *tctx,
talloc_free(path);
}
- /* give a bit of time for the events to propogate */
+ /* give a bit of time for the events to propagate */
tv = timeval_current();
do {